@@ -169,6 +169,8 @@ pub fn expand(callee: &Ident, attr: Config) -> Result<Vec<ItemFn>, Error> {
                 #[ignore]
                 #[doc(hidden)]
                 fn test_ident() {
+                    eprintln!("Input: {}", path_str);
+
                     callee(::std::path::PathBuf::from(path_str));
                 }
             }
@@ -194,5 +196,9 @@ pub fn expand(callee: &Ident, attr: Config) -> Result<Vec<ItemFn>, Error> {
         test_fns.push(f);
     }
 
+    if test_fns.is_empty() {
+        panic!("No test found")
+    }
+
     Ok(test_fns)
 }
